@@ -23,14 +23,15 @@ class CacheItem(object):
         return str(self.value)
 
 
-class CacheBuilder(object):
+class _CacheBuilder(object):
 
     def __init__(self, root_dir=None, keep_in_memory=True):
         self.root_dir = root_dir
         self.keep_in_memory = keep_in_memory
-        self._manager = multiprocessing.Manager()
         self.reset_handlers()
 
+
+
     def reset_handlers(self):
         self._type_handlers = list()
 
@@ -46,18 +47,63 @@ class CacheBuilder(object):
                                     )
                                    )
 
+
     def __call__(self, function):
         folder = function.__name__
         if self.root_dir is not None:
             folder = os.path.join(self.root_dir, folder)
 
+        cache, lock, counter, handlers = self._setup_cache_internals()
+
+        c = _CachedFunction(function, folder, self.keep_in_memory, lock, cache, counter, handlers)
+        return c
+
+
+class CacheBuilder(_CacheBuilder):
+
+    def __init__(self, root_dir=None, keep_in_memory=True):
+        super(CacheBuilder, self).__init__(root_dir, keep_in_memory)
+        self._manager = multiprocessing.Manager()
+
+    def _setup_cache_internals(self):
         cache = self._manager.dict()
         lock = self._manager.Lock()
         counter = self._manager.Value('d', 0)
         handlers = self._manager.list(self._type_handlers)
+        return cache, lock, counter, handlers
 
-        c = _CachedFunction(function, folder, self.keep_in_memory, lock, cache, counter, handlers)
-        return c
+
+class LocalCounter(object):
+
+    def __init__(self):
+        self.value = 0
+
+
+class NoOpContextManager(object):
+
+    def __enter__(self, *a, **kw):
+        pass
+
+    __exit__ = __enter__
+
+
+class LocalCacheBuilder(_CacheBuilder):
+
+    """Cache which only resists in current process, can not be used with pacerd distributed
+    computation capabilities ! Use CacheBuilder instead.
+    """
+
+    def __init__(self, root_dir=None, keep_in_memory=True):
+        super(LocalCacheBuilder, self).__init__(root_dir, keep_in_memory)
+        self._manager = None
+
+
+    def _setup_cache_internals(self):
+        cache = dict()
+        lock = NoOpContextManager()
+        counter = LocalCounter()
+        handlers = list(self._type_handlers)
+        return cache, lock, counter, handlers
 
 
 class _CachedFunction(object):
